@@ -35,10 +35,9 @@ public:
 //          qint64 readUsedCapacity(const QString& deviceNode) const override;
     bool check(Report& report, const QString& deviceNode) const override;
     bool create(Report& report, const QString& deviceNode) override;
-    bool createWithLabel(Report& report, const QString& deviceNode, const QString& label) override;
 //     qint64 readUsedCapacity(const QString& deviceNode) const override;
     bool resize(Report& report, const QString& deviceNode, qint64 length) const override;
-//     bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
+    bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
 //     bool updateUUID(Report& report, const QString& deviceNode) const override;
     QString posixPermissions() const override { return implPosixPermissions();  };
     void setPosixPermissions(const QString& permissions) override { implSetPosixPermissions(permissions); };
@@ -52,9 +51,6 @@ public:
     CommandSupportType supportCreate() const override {
         return m_Create;
     }
-    CommandSupportType supportCreateWithLabel() const override {
-        return m_Create;
-    }
     CommandSupportType supportGrow() const override {
         return m_Grow;
     }
@@ -102,10 +98,6 @@ public:
     static CommandSupportType m_SetLabel;
     static CommandSupportType m_UpdateUUID;
     static CommandSupportType m_GetUUID;
-
-private:
-    static bool oldVersion;
-
 };
 }
 
